==> xray_audit-1.0.0.tar.gz: xray_audit/src/Controller/XrayAuditGroupsController.php <==
<?php

namespace Drupal\xray_audit\Controller;

use Drupal\Core\Url;
use Drupal\Core\Render\RendererInterface;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Component\Plugin\PluginManagerInterface;
use Drupal\xray_audit\Plugin\XrayAuditGroupPluginInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Returns responses for the list of groups.
 */
class XrayAuditGroupsController extends ControllerBase {

  /**
   * Plugin manager.
   *
   * @var \Drupal\Component\Plugin\PluginManagerInterface
   */
  protected $pluginManager;

  /**
   * Renderer serive.
   *
   * @var \Drupal\Core\Render\RendererInterface
   */
  protected $renderer;

  /**
   * Constructs of Controller.
   *
   * @param \Drupal\Component\Plugin\PluginManagerInterface $plugin_manager
   *   Plugin manager for Groups.
   * @param \Drupal\Core\Render\RendererInterface $renderer
   *   Service renderer.
   */
  public function __construct(PluginManagerInterface $plugin_manager, RendererInterface $renderer) {
    $this->pluginManager = $plugin_manager;
    $this->renderer = $renderer;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('plugin_manager.xray_audit_group'),
      $container->get('renderer'),
    );
  }

  /**
   * Builds the home response.
   *
   * @return array
   *   Render array.
   */
  public function buildHome(): array {
    $groupDefinitions = $this->pluginManager->getDefinitions();
    if (empty($groupDefinitions)) {
      return [];
    }
    usort($groupDefinitions, function ($a, $b) {
      return ($a['sort'] ?? 0) <=> ($b['sort'] ?? 0);
    });

    foreach ($groupDefinitions as $group_definition) {
      $groups[] = [
        'title' => (string) $group_definition['label'],
        'url' => Url::fromRoute(
          'xray_audit.group_page',
          ['group_plugin' => $group_definition['id']]
        ),
        'localized_options' => [],
        'description' => (string) $group_definition['description'],
      ];
    }
    return [
      '#theme' => 'admin_block_content',
      '#content' => $groups,
    ];
  }

  /**
   * Build group page.
   *
   * @param string $group_plugin
   *   Group plugin id.
   *
   * @return array
   *   Render array.
   */
  public function buildGroup(string $group_plugin): array {

    $build = [];

    /** @var \Drupal\xray_audit\Plugin\XrayAuditGroupPluginInterface $group_plugin_instance * */
    $group_plugin_instance = $this->pluginManager->createInstance($group_plugin);
    if (!$group_plugin_instance instanceof XrayAuditGroupPluginInterface) {
      return $build;
    }
    $task_definitions = $group_plugin_instance->getPluginTaskDefinitionsThisGroup();
    if (empty($task_definitions)) {
      return $build;
    }

    $header = [
      $this->t('Title'),
      $this->t('Description'),
      $this->t('Operations'),
    ];

    $rows = [];
    foreach ($task_definitions as $task_definition) {

      $links = [];
      $weight = 0;
      foreach ($task_definition['operations'] as $key_operation => $operation) {
        $weight += 10;
        $links[$key_operation] = [
          'title' => $operation['label'] ?? '',
          'weight' => $weight,
          'url' => Url::fromRoute(
            'xray_audit.task_page',
            [
              'group_plugin' => $group_plugin,
              'task_plugin' => $task_definition['id'],
              'operation' => $key_operation,
            ]
          ),
        ];
      }

      $operations_render = [
        '#type' => 'operations',
        '#links' => $links,
      ];

      $rows[] = [
        'title' => $task_definition['label'],
        'description' => $task_definition['description'],
        'operations' => $this->renderer->render($operations_render),
      ];

    }

    $build['table'] = [
      '#theme' => 'table',
      '#header' => $header,
      '#rows' => $rows,
    ];

    return $build;
  }

  /**
   * Get title.
   *
   * @param string $group_plugin
   *   Group plugin id.
   *
   * @return string
   *   Title.
   */
  public function getTitle(string $group_plugin): string {
    $title = '';
    /** @var \Drupal\xray_audit\Plugin\XrayAuditGroupPluginInterface $group_plugin_instance * */
    $group_plugin_instance = $this->pluginManager->createInstance($group_plugin);
    if (!$group_plugin_instance instanceof XrayAuditGroupPluginInterface) {
      return $title;
    }
    return $group_plugin_instance->label();
  }

}

==> xray_audit-1.3.2.tar.gz: xray_audit/src/Controller/XrayAuditGroupsController.php <==
<?php

namespace Drupal\xray_audit\Controller;

use Drupal\Core\Render\RendererInterface;
use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\xray_audit\Services\PluginRepositoryInterface;

/**
 * Returns responses for the list of groups.
 */
class XrayAuditGroupsController extends ControllerBase {

  /**
   * Plugin repository.
   *
   * @var \Drupal\xray_audit\Services\PluginRepositoryInterface
   */
  protected $pluginRepository;

  /**
   * Renderer service.
   *
   * @var \Drupal\Core\Render\RendererInterface
   */
  protected $renderer;

  /**
   * Constructs of Controller.
   *
   * @param \Drupal\xray_audit\Services\PluginRepositoryInterface $plugin_repository
   *   Plugin manager for Groups.
   * @param \Drupal\Core\Render\RendererInterface $renderer
   *   Service renderer.
   */
  public function __construct(PluginRepositoryInterface $plugin_repository, RendererInterface $renderer) {
    $this->pluginRepository = $plugin_repository;
    $this->renderer = $renderer;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('xray_audit.plugin_repository'),
      $container->get('renderer'),
    );
  }

  /**
   * Builds the home response.
   *
   * @return array
   *   Render array.
   */
  public function buildHome(): array {
    $groupDefinitions = $this->pluginRepository->getGroupPluginDefinitions();
    if (empty($groupDefinitions)) {
      return [];
    }
    usort($groupDefinitions, function ($a, $b) {
      return ($a['sort'] ?? 0) <=> ($b['sort'] ?? 0);
    });

    foreach ($groupDefinitions as $group_definition) {
      $groups[] = [
        'title' => (string) $group_definition['label'],
        'url' => $this->pluginRepository->getGroupPageUrl($group_definition['id']),
        'localized_options' => [],
        'description' => (string) $group_definition['description'],
      ];
    }
    return [
      '#theme' => 'admin_block_content',
      '#content' => $groups,
    ];
  }

  /**
   * Build group page.
   *
   * @param string $group_plugin
   *   Group plugin id.
   *
   * @return array
   *   Render array.
   */
  public function buildGroup(string $group_plugin): array {

    $build = [];

    $group_plugin_instance = $this->pluginRepository->getInstancePluginGroup($group_plugin);
    if ($group_plugin_instance === NULL) {
      return $build;
    }

    $task_definitions = $group_plugin_instance->getPluginTaskDefinitionsThisGroup();
    if (empty($task_definitions)) {
      return $build;
    }

    $header = [
      $this->t('Title'),
      $this->t('Description'),
      $this->t('Operations'),
    ];

    $rows = [];
    foreach ($task_definitions as $task_definition) {

      $links = [];
      $weight = 0;
      foreach ($task_definition['operations'] as $key_operation => $operation) {
        $weight += 10;
        $links[$key_operation] = [
          'title' => $operation['label'] ?? '',
          'weight' => $weight,
          'url' => $this->pluginRepository->getTaskPageOperationUrl($group_plugin, $task_definition['id'], $key_operation),
        ];
      }

      $operations_render = [
        '#type' => 'operations',
        '#links' => $links,
      ];

      $rows[] = [
        'title' => $task_definition['label'],
        'description' => $task_definition['description'],
        'operations' => $this->renderer->render($operations_render),
      ];

    }

    $build['table'] = [
      '#theme' => 'table',
      '#header' => $header,
      '#rows' => $rows,
    ];

    return $build;
  }

  /**
   * Get title.
   *
   * @param string $group_plugin
   *   Group plugin id.
   *
   * @return string
   *   Title.
   */
  public function getTitle(string $group_plugin): string {
    $title = '';
    $group_plugin_instance = $this->pluginRepository->getInstancePluginGroup($group_plugin);
    if ($group_plugin_instance === NULL) {
      return $title;
    }
    return $group_plugin_instance->label();

  }

}
